==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_functions/mp7080_001/MP7080_SyncStandardWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp7080_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardworkorder_001.StandardWorkOrder;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="StandardWorkOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="SyncStandardWorkOrder" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardWorkOrder"
})
@XmlRootElement(name = "MP7080_SyncStandardWorkOrder_001")
public class MP7080_SyncStandardWorkOrder_001 {

    @XmlElement(name = "StandardWorkOrder", namespace = "http://schemas.datastream.net/MP_entities/StandardWorkOrder_001", required = true)
    protected StandardWorkOrder standardWorkOrder;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;

    /**
     * Obtient la valeur de la propriété standardWorkOrder.
     * 
     * @return
     *     possible object is
     *     {@link StandardWorkOrder }
     *     
     */
    public StandardWorkOrder getStandardWorkOrder() {
        return standardWorkOrder;
    }

    /**
     * Définit la valeur de la propriété standardWorkOrder.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardWorkOrder }
     *     
     */
    public void setStandardWorkOrder(StandardWorkOrder value) {
        this.standardWorkOrder = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STANDARD_WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété callname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "SyncStandardWorkOrder";
        } else {
            return callname;
        }
    }

    /**
     * Définit la valeur de la propriété callname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_functions/mp7080_001/MP7080_SyncStandardWorkOrder_001.java <==

package net.datastream.schemas.mp_functions.mp7080_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardworkorder_001.StandardWorkOrder;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="StandardWorkOrder" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="SyncStandardWorkOrder" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "standardWorkOrder"
})
@XmlRootElement(name = "MP7080_SyncStandardWorkOrder_001")
public class MP7080_SyncStandardWorkOrder_001 {

    @XmlElement(name = "StandardWorkOrder", namespace = "http://schemas.datastream.net/MP_entities/StandardWorkOrder_001", required = true)
    protected StandardWorkOrder standardWorkOrder;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;

    /**
     * Gets the value of the standardWorkOrder property.
     * 
     * @return
     *     possible object is
     *     {@link StandardWorkOrder }
     *     
     */
    public StandardWorkOrder getStandardWorkOrder() {
        return standardWorkOrder;
    }

    /**
     * Sets the value of the standardWorkOrder property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardWorkOrder }
     *     
     */
    public void setStandardWorkOrder(StandardWorkOrder value) {
        this.standardWorkOrder = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.STANDARD_WORK_ORDER;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "SyncStandardWorkOrder";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

}
